.. archiving.core.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive._archiving._core package.



AutoArchive._archiving._core
============================

.. automodule:: AutoArchive._archiving._core
   :no-members:



Modules
-------

archiving_component
^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._archiving._core.archiving_component



_archiver_manipulator
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._archiving._core._archiver_manipulator
.. autoclass:: _ArchiverManipulator



_backup_information_provider
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._archiving._core._backup_information_provider
.. autoclass:: _BackupInformationProvider



_archiving_constants
^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._archiving._core._archiving_constants
.. autoclass:: _ArchiverMaps
.. autoclass:: _RestartStorageVariables



_archive_spec
^^^^^^^^^^^^^

.. automodule:: AutoArchive._archiving._core._archive_spec
.. autoclass:: _ArchiveSpec
.. autoclass:: _ArchiveSpecOptions
